@@ -36,8 +36,3 @@ class Incomes(Resource):
 
     def delete(self, id: str) -> bool:
         raise NotImplementedError()
-
-    def resume(
-        self, session: str, token: str, *, link: str = None, raise_exception: bool = False, **kwargs
-    ) -> Union[List[Dict], Dict]:
-        raise NotImplementedError()
